print("Timurids Scripts")

include("FLuaVector.lua")

function PositionCalculator(i1, i2)
	return HexToWorld(ToHexFromGrid(Vector2(i1, i2)))
end

local bTimDummy = GameInfoTypes.BUILDING_TIMURID_MOD_DUMMY
local bUniqCaptureDummy = GameInfoTypes.BUILDING_UNIQUE_CAPTURE_DUMMY
local TimuridsID = GameInfoTypes.CIVILIZATION_TIMURIDS_MOD
local L = Locale.ConvertTextKey
local tBuildings = {}
local tWaterBuildings = {}

-- Trade Route Yields -- adds dummy buildings to Registan, based on number of International Trade Routes in/out of the Timurid Capital.
function MadrasahTradeYields(PlayerID)
	local pPlayer = Players[PlayerID]

	if not pPlayer:GetCivilizationType() == TimuridsID then return end 

	print("Trade out!")

	local pCapital = pPlayer:GetCapitalCity()
	local tTradeRoutes = pPlayer:GetTradeRoutes()
	local iCounter = 0

	for i, tradeRoute in ipairs(tTradeRoutes) do
		if (tradeRoute.FromCity:IsHasBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_MOD) and tradeRoute.ToCivilizationType ~= TimuridsID) or (tradeRoute.ToCity:IsHasBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_MOD) and tradeRoute.FromCivilizationType ~= TimuridsID) then
			iCounter = iCounter + 1
		end
	end
	
	if pCapital then
		if pCapital:IsHasBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_1_MOD) then
			pCapital:SetNumRealBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_1_DUMMY, iCounter)
		end
		if pCapital:IsHasBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_2_MOD) then
			pCapital:SetNumRealBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_2_DUMMY, iCounter)
		end
		if pCapital:IsHasBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_3_MOD) then
			pCapital:SetNumRealBuilding(GameInfoTypes.BUILDING_TIMURID_MADRASAH_3_DUMMY, iCounter)
		end
	end
end
GameEvents.PlayerDoTurn.Add(MadrasahTradeYields)

-- Jewel of the East UA of Timurids - all conquered buildings are immediately built in capital; consist of 2 functions to achieve UBs; yields on conquer if not conquered before
function JewelOfTheEast1(iPlayer, iUnitOrCity, iRole, bIsCity)
    if not (bIsCity and iRole == 1) then return end
 
    local pPlayer = Players[iPlayer]
 
    if not pPlayer then return end
 
    local pCity = pPlayer:GetCityByID(iUnitOrCity)
    tBuildings = {}
    tWaterBuildings = {}
 
    for building in GameInfo.Buildings() do
        if pCity:IsHasBuilding(building.ID) and (not building.NukeImmune or building.ID == GameInfoTypes.BUILDING_MILITARY_BASE) and building.HurryCostModifier ~= -1 then -- no wonders or dummies
            local bIsUnique = false
            local bIsFound = false
         
            for uniqueBuilding in DB.Query("select * from Civilization_BuildingClassOverrides where BuildingType = ?", building.Type) do
                bIsUnique = true
             
                for equivalentBuilding in GameInfo.Buildings() do
                    if equivalentBuilding.BuildingClass == uniqueBuilding.BuildingClassType then
                        local bIsBaseBuilding = true
                     
                        for equivalentUniqueBuilding in DB.Query("select * from Civilization_BuildingClassOverrides where BuildingType = ?", equivalentBuilding.Type) do
                            bIsBaseBuilding = false
                        end
                     
                        if bIsBaseBuilding then
                            bIsFound = true
                         
                            if equivalentBuilding.Water then
                                table.insert(tWaterBuildings, equivalentBuilding)
                            else
                                table.insert(tBuildings, equivalentBuilding)
                            end
                         
                            break
                        end
                    end
                end
             
                if bIsFound then
                    break
                end
            end
         
            if not bIsUnique then
                if building.Water then
                    table.insert(tWaterBuildings, building)
                else
                    table.insert(tBuildings, building)
                end
            end        
        end
    end
end
GameEvents.BattleJoined.Add(JewelOfTheEast1)

function JewelOfTheEast2(iOldOwner, bIsCapital, iX, iY, iNewOwner, iPop, bConquest)
    -- buildings part
    local pPlayer = Players[iNewOwner]
    local pCapital = pPlayer:GetCapitalCity()
    local pCapitalX, pCapitalY, pCapitalID = pCapital:GetX(), pCapital:GetY(), pCapital:GetID()
    local sName = pCapital:GetName()
    local iCoastalBuildings = 0
 
    if not (pPlayer and pPlayer:GetCivilizationType() == TimuridsID) then return end

    -- yields part - on City Capture, if City has never been captured before, give capital a bonus
    local pCity = Map.GetPlot(iX, iY):GetPlotCity()
 
    if pCity:GetNumBuilding(bUniqCaptureDummy) == 0 then
		local CapYield = (1 + math.max(pPlayer:GetCurrentEra(), 1))
        pCapital:SetNumRealBuilding(bTimDummy, (pCapital:GetNumBuilding(bTimDummy) + CapYield))
        pCity:SetNumRealBuilding(bUniqCaptureDummy, 1)
 
        if pPlayer:IsHuman() and pPlayer:IsTurnActive() then
            local vCityPosition = PositionCalculator(pCapitalX, pCapitalY)
         
            pPlayer:AddNotification(NotificationTypes.NOTIFICATION_INSTANT_YIELD,
                'Your Palace in [COLOR_POSITIVE_TEXT]'..sName..'[ENDCOLOR] has gained more yields: +'..CapYield..' [ICON_CULTURE] Culture, +'..CapYield..' [ICON_RESEARCH] Science, +'..CapYield..' [ICON_GOLD] Gold, +'..CapYield..' [ICON_PEACE] Faith, and  +'..CapYield..' [ICON_PRODUCTION] Production',
                'Artisans captured and brought to '..sName,
                pCapitalX, pCapitalY, pCapitalID)
        end
    end
 
    if pCapital:IsCoastal() then
        iCoastalBuildings = #tWaterBuildings
    end
 
    local iNumberOfBuildings = #tBuildings + iCoastalBuildings
 
    if iNumberOfBuildings == 0 then return end
     
    local sCitiesNames = ""
 
    for i, building in pairs(tBuildings) do
        if not pCapital:IsHasBuilding(building.ID) then        
            pCapital:SetNumRealBuilding(building.ID, 1)
         
            if i - iCoastalBuildings == iNumberOfBuildings then
                sCitiesNames = sCitiesNames .. " and " .. L(building.Description)
            elseif sCitiesNames == "" then
                sCitiesNames = sCitiesNames .. L(building.Description)
            else
                sCitiesNames = sCitiesNames .. ", " .. L(building.Description)
            end
        end
    end
 
    if pCapital:IsCoastal() then
        for i, building in pairs(tWaterBuildings) do
            if not pCapital:IsHasBuilding(building.ID) then        
                pCapital:SetNumRealBuilding(building.ID, 1)
             
                if i == #tWaterBuildings then
                    sCitiesNames = sCitiesNames .. " and " .. L(building.Description)
                elseif sCitiesNames == "" then
                    sCitiesNames = sCitiesNames .. L(building.Description)
                else
                    sCitiesNames = sCitiesNames .. ", " .. L(building.Description)
                end
            end
        end
    end
 
    if pPlayer:IsHuman() and pPlayer:IsTurnActive() then
        local sText = "Foreign architects have constructed following buildings in your [ICON_CAPITAL] Capital: " .. sCitiesNames .. "."
        local sTitle = "Jewel of the East"
     
        pPlayer:AddNotification(NotificationTypes.NOTIFICATION_WONDER_COMPLETED,
            sText,
            sTitle,
            pCapitalX, pCapitalY, GameInfoTypes.BUILDING_PALACE, -1)
    end
end
GameEvents.CityCaptureComplete.Add(JewelOfTheEast2)

-- Permanent yields on city raze -- Adds yields via dummy building to Capital every time Timurids raze a city
function CapitalBonusOnRaze(hexPos, iOldOwner, cityID, iNewOwner)
	local pPlayer = Players[iOldOwner]
		print(pPlayer:GetName())
	local pCapital = pPlayer:GetCapitalCity()
	local pCapitalX, pCapitalY, pCapitalID = pCapital:GetX(), pCapital:GetY(), pCapital:GetID()
	local sName = pCapital:GetName()
	
	if pPlayer:GetCivilizationType() == TimuridsID then
		local CapYield = (1 + math.max(pPlayer:GetCurrentEra(), 1))
		pCapital:SetNumRealBuilding(bTimDummy, (pCapital:GetNumBuilding(bTimDummy) + CapYield))
		
		if pPlayer:IsHuman() and pPlayer:IsTurnActive() then
			local vCityPosition = PositionCalculator(pCapitalX, pCapitalY)
			
			pPlayer:AddNotification(NotificationTypes.NOTIFICATION_INSTANT_YIELD,
				'Your Palace in [COLOR_POSITIVE_TEXT]'..sName..'[ENDCOLOR] has gained more yields: +'..CapYield..' [ICON_CULTURE] Culture, +'..CapYield..' [ICON_RESEARCH] Science, +'..CapYield..' [ICON_GOLD] Gold, +'..CapYield..' [ICON_PEACE] Faith, and  +'..CapYield..' [ICON_PRODUCTION] Production',
				'Artisans fled to '..sName,
				pCapitalX, pCapitalY, pCapitalID)
		end
	end
end
Events.SerialEventCityDestroyed.Add(CapitalBonusOnRaze)