--Decisions
CREATE TABLE IF NOT EXISTS DecisionsAddin_Support(FileName);
INSERT INTO DecisionsAddin_Support (FileName) VALUES ('TomatekhTimuridDecisions.lua');

--Ethnic Units
UPDATE Civilizations SET ArtStyleSuffix = 
	( CASE WHEN EXISTS(SELECT ArtStyleSuffix FROM Civilizations WHERE ArtStyleSuffix = "_MONGOL")
		THEN "_MONGOL"
		ELSE "_AFRI" END
	) WHERE Type = "CIVILIZATION_TIMURIDS_MOD";

--Map Labels
CREATE TABLE IF NOT EXISTS ML_CivCultures (ID INTEGER PRIMARY KEY AUTOINCREMENT, CivType TEXT, CultureType TEXT, CultureEra TEXT DEFAULT 'ANY');
INSERT INTO ML_CivCultures
			(CivType,						       CultureType,	CultureEra)
VALUES		('CIVILIZATION_TIMURIDS_MOD',		     'ARABIAN',		 'ANY'),
			('CIVILIZATION_TIMURIDS_MOD',		  'EAST_ASIAN',	     'ANY');

--JFD
CREATE TABLE IF NOT EXISTS 
JFD_GlobalUserSettings (
    Type                                        text                                        default null,
    Value                                       integer                                     default 1);

--Piety
INSERT OR REPLACE INTO Flavors
            (Type)
VALUES      ('FLAVOR_JFD_RELIGIOUS_INTOLERANCE');
 
INSERT INTO Leader_Flavors
            (LeaderType,									FlavorType,    Flavor)
VALUES      ('LEADER_TIMUR_MOD',    'FLAVOR_JFD_RELIGIOUS_INTOLERANCE',         8);

--Prestige
CREATE TABLE IF NOT EXISTS 
    Civilization_JFD_Governments (
    CivilizationType                text        REFERENCES Civilizations(Type)                  default null,
    CultureType                     text                                                        default null,
    LegislatureName                 text                                                        default null,
    OfficeTitle                     text                                                        default null,
    GovernmentType                  text                                                        default null,
    Weight                          integer                                                     default 0);

CREATE TABLE IF NOT EXISTS  
    Civilization_JFD_HeadsOfGovernment (    
    CivilizationType                text        REFERENCES Civilizations(Type)                  default null,
    CultureType                     text                                                        default null,
    HeadOfGovernmentName            text                                                        default null);

CREATE TABLE IF NOT EXISTS 
    Civilization_JFD_Titles (
    CivilizationType                text        REFERENCES Civilizations(Type)                  default null,
    CultureType                     text                                                        default null,
    ReligionType                    text        REFERENCES Religions(Type)                      default null,
    DefaultTitle                    text                                                        default null,
    UniqueTitle                     text                                                        default null,
    UseAdjective                    boolean                                                     default 0); 

CREATE TABLE IF NOT EXISTS 
    Civilization_JFD_Politics (
    CivilizationType                    text        REFERENCES Civilizations(Type)                  default null,
    PoliticsType                        text                                                        default null,
    UniqueName                          text                                                        default null);

INSERT INTO Civilization_JFD_Governments
        (CivilizationType,          LegislatureName, OfficeTitle, GovernmentType, Weight)
SELECT  ('CIVILIZATION_TIMURIDS_MOD'), LegislatureName, OfficeTitle, GovernmentType, Weight
FROM Civilization_JFD_Governments WHERE CivilizationType = 'CIVILIZATION_PERSIA';

INSERT INTO Civilization_JFD_HeadsOfGovernment
        (CivilizationType,          HeadOfGovernmentName)
SELECT  ('CIVILIZATION_TIMURIDS_MOD'), HeadOfGovernmentName
FROM Civilization_JFD_HeadsOfGovernment WHERE CivilizationType = 'CIVILIZATION_PERSIA';

INSERT INTO Civilization_JFD_Titles
        (CivilizationType,          DefaultTitle,   UniqueTitle)
SELECT  ('CIVILIZATION_TIMURIDS_MOD'), DefaultTitle,   UniqueTitle
FROM Civilization_JFD_Titles WHERE CivilizationType = 'CIVILIZATION_PERSIA';

INSERT INTO Civilization_JFD_Politics
        (CivilizationType,          PoliticsType, UniqueName)
SELECT  ('CIVILIZATION_TIMURIDS_MOD'), PoliticsType, UniqueName
FROM Civilization_JFD_Politics WHERE CivilizationType = 'CIVILIZATION_PERSIA';

INSERT OR REPLACE INTO Flavors 
        (Type)
VALUES  ('FLAVOR_JFD_REFORM_GOVERNMENT'),
        ('FLAVOR_JFD_REFORM_CULTURE'),
        ('FLAVOR_JFD_REFORM_ECONOMIC'),
        ('FLAVOR_JFD_REFORM_FOREIGN'),
        ('FLAVOR_JFD_REFORM_INDUSTRY'),
        ('FLAVOR_JFD_REFORM_MILITARY'),
        ('FLAVOR_JFD_REFORM_RELIGION');

INSERT INTO Leader_Flavors
        (LeaderType,							            FlavorType,                         Flavor)
VALUES  ('LEADER_TIMUR_MOD',			'FLAVOR_JFD_REFORM_GOVERNMENT',                              8),
        ('LEADER_TIMUR_MOD',			   'FLAVOR_JFD_REFORM_CULTURE',                              2),
        ('LEADER_TIMUR_MOD',			  'FLAVOR_JFD_REFORM_ECONOMIC',                              5),
        ('LEADER_TIMUR_MOD',			   'FLAVOR_JFD_REFORM_FOREIGN',                              2),
        ('LEADER_TIMUR_MOD',			  'FLAVOR_JFD_REFORM_INDUSTRY',                              5),
        ('LEADER_TIMUR_MOD',			  'FLAVOR_JFD_REFORM_RELIGION',                              8);

--Cultural Diversity
CREATE TABLE IF NOT EXISTS 
Civilization_JFD_CultureTypes(
	CivilizationType 							text 	REFERENCES Civilizations(Type) 			default null,
	CultureType 								text											default null,
	ArtDefineTag								text											default	null,
	SplashScreenTag								text											default	null,
	SoundtrackTag								text											default	null,
	UnitDialogueTag								text											default null);

INSERT INTO Civilization_JFD_CultureTypes
		(CivilizationType,					ArtDefineTag, CultureType, SplashScreenTag, SoundtrackTag, UnitDialogueTag)
SELECT	('CIVILIZATION_TIMURIDS_MOD'),	ArtDefineTag, ('JFD_Steppe'), SplashScreenTag, SoundtrackTag, ('AS2D_SOUND_JFD_PERSIAN')
FROM Civilization_JFD_CultureTypes WHERE CivilizationType = 'CIVILIZATION_ARABIA';

UPDATE Civilizations 
SET SoundtrackTag = 'JFD_Islamic'
WHERE Type = 'CIVILIZATION_TIMURIDS_MOD'
AND EXISTS (SELECT * FROM Civilization_JFD_CultureTypes WHERE SoundtrackTag = 'JFD_Islamic')
AND EXISTS (SELECT * FROM JFD_GlobalUserSettings WHERE Type = 'JFD_CULDIV_SOUNDTRACK_ADDON' AND Value = 1);

--Civ IV Traits
CREATE TABLE IF NOT EXISTS 
    Leader_SharedTraits (
    LeaderType          text    REFERENCES Leaders(Type)        default null,
    TraitOne            text    REFERENCES Policies(Type)       default null,
    TraitTwo            text    REFERENCES Policies(Type)       default null);
     
INSERT OR REPLACE INTO Leader_SharedTraits
			(LeaderType,									          TraitOne,					  TraitTwo)
SELECT		('LEADER_TIMUR_MOD'),	                ('POLICY_IMPERIALISTIC_X'),	   ('POLICY_CHARISMATIC_X')
WHERE EXISTS (SELECT Type FROM Policies WHERE Type = 'POLICY_PHILOSOPHICAL_X');

UPDATE Leaders 
SET Description = (CASE WHEN EXISTS(SELECT Type FROM Policies WHERE Type = 'POLICY_PHILOSOPHICAL_X' )
	THEN 'Timur[ICON_CITY_STATE][ICON_HAPPINESS_1]'
	ELSE 'TXT_KEY_LEADER_TIMUR_MOD_DESC' END) 
WHERE Type = 'LEADER_TIMUR_MOD';

CREATE TRIGGER CivIVTraitsTimur
AFTER INSERT ON Leaders WHEN 'LEADER_TIMUR_MOD' = NEW.Type
BEGIN
	UPDATE Leaders 
	SET Description = (CASE WHEN EXISTS(SELECT Type FROM Policies WHERE Type = 'POLICY_PHILOSOPHICAL_X' )
		THEN 'Timur[ICON_CITY_STATE][ICON_HAPPINESS_1]'
		ELSE 'TXT_KEY_LEADER_TIMUR_MOD_DESC' END) 
	WHERE Type = 'LEADER_TIMUR_MOD';
END;	

--ExCE
CREATE TABLE IF NOT EXISTS 
Civilization_JFD_ColonialCityNames (
	CivilizationType 							text 	REFERENCES Civilizations(Type) 		default null,
	ColonyName 									text										default null,
	LinguisticType								text										default	null,
	CultureType									text										default	null);

INSERT OR REPLACE INTO Civilization_JFD_ColonialCityNames
			(CivilizationType, 						ColonyName,								LinguisticType)
VALUES		('CIVILIZATION_TIMURIDS_MOD', 			null,									'JFD_Altaic'),
			('CIVILIZATION_TIMURIDS_MOD', 			null,									'JFD_Indo_Iranian');

CREATE TABLE IF NOT EXISTS 
Civilization_JFD_RevolutionaryCivilizationsToSpawn (
	CivilizationType 							text 	REFERENCES Civilizations(Type) 		default null,
	RevolutionaryCivilizationType 				text 	REFERENCES Civilizations(Type) 		default null);
	
INSERT INTO Civilization_JFD_RevolutionaryCivilizationsToSpawn
			(CivilizationType,				RevolutionaryCivilizationType)
VALUES		('CIVILIZATION_PERSIA',			'CIVILIZATION_TIMURIDS_MOD'),
			('CIVILIZATION_TIMURIDS_MOD',	'CIVILIZATION_PERSIA');

INSERT INTO Civilization_JFD_RevolutionaryCivilizationsToSpawn
			(CivilizationType,					RevolutionaryCivilizationType)
SELECT		('CIVILIZATION_TIMURIDS_MOD'),		('CIVILIZATION_MUGHAL')
WHERE EXISTS (SELECT Type FROM Civilizations WHERE Type = 'CIVILIZATION_MUGHAL');

INSERT INTO Civilization_JFD_RevolutionaryCivilizationsToSpawn
			(CivilizationType,					RevolutionaryCivilizationType)
SELECT		('CIVILIZATION_TIMURIDS_MOD'),		('CIVILIZATION_MC_MUGHAL')
WHERE EXISTS (SELECT Type FROM Civilizations WHERE Type = 'CIVILIZATION_MC_MUGHAL');

--Mercenaries 
INSERT OR REPLACE INTO Flavors 
        (Type)
VALUES  ('FLAVOR_JFD_MERCENARY');

INSERT INTO Leader_Flavors
        (LeaderType,									 FlavorType,                 Flavor)
VALUES  ('LEADER_TIMUR_MOD',                 'FLAVOR_JFD_MERCENARY',                      8);

--Cultural Development
CREATE TABLE IF NOT EXISTS 
Events_CulturalDevelopments(
	CivilizationType		text  REFERENCES Civilizations(Type)	default null,
	CultureType				text									default null,
	Description				text									default null);

INSERT INTO Events_CulturalDevelopments 
			(Description,								                            CivilizationType,						CultureType)
VALUES		('TXT_KEY_EVENT_CULDEV_TOMATEKH_TIMURIDS_01',			     'CIVILIZATION_TIMURIDS_MOD',					           null);

--EE
DELETE FROM Unit_ClassUpgrades WHERE UnitType = 'UNIT_TIMURID_GHAZI_MOD' AND EXISTS (SELECT * FROM Units WHERE Type = 'UNIT_EE_UHLAN');

INSERT INTO Unit_ClassUpgrades
			(UnitType, UnitClassType)
SELECT		('UNIT_TIMURID_GHAZI_MOD'),	('UNITCLASS_EE_UHLAN')		 
WHERE EXISTS (SELECT * FROM Units WHERE Type = 'UNIT_EE_UHLAN');

UPDATE Units
SET ObsoleteTech = 'TECH_MILITARY_SCIENCE'
WHERE Type = 'UNIT_TIMURID_GHAZI_MOD'
AND EXISTS (SELECT * FROM Units WHERE TYPE = 'UNIT_EE_UHLAN');

UPDATE Units
SET GoodyHutUpgradeUnitClass = 'UNITCLASS_EE_UHLAN'
WHERE Type = 'UNIT_TIMURID_GHAZI_MOD'
AND EXISTS (SELECT * FROM Units WHERE TYPE = 'UNIT_EE_UHLAN');

CREATE TRIGGER TimuridLancerEE
AFTER INSERT ON Buildings WHEN 'BUILDING_EE_CRYSTAL_PALACE' = NEW.TYPE
BEGIN

	DELETE FROM Unit_ClassUpgrades WHERE UnitType = 'UNIT_TIMURID_GHAZI_MOD' AND EXISTS (SELECT * FROM Units WHERE Type = 'UNIT_EE_UHLAN');

	INSERT INTO Unit_ClassUpgrades
				(UnitType, UnitClassType)
	SELECT		('UNIT_TIMURID_GHAZI_MOD'),	('UNITCLASS_EE_UHLAN')		 
	WHERE EXISTS (SELECT * FROM Units WHERE Type = 'UNIT_EE_UHLAN');

	UPDATE Units
	SET ObsoleteTech = 'TECH_MILITARY_SCIENCE'
	WHERE Type = 'UNIT_TIMURID_GHAZI_MOD'
	AND EXISTS (SELECT * FROM Units WHERE TYPE = 'UNIT_EE_UHLAN');

	UPDATE Units
	SET GoodyHutUpgradeUnitClass = 'UNITCLASS_EE_UHLAN'
	WHERE Type = 'UNIT_TIMURID_GHAZI_MOD'
	AND EXISTS (SELECT * FROM Units WHERE TYPE = 'UNIT_EE_UHLAN');

END;